@@ -54,10 +54,10 @@ def get_terminal_size(default=0):
     of the terminal cannot be determined of if the width is less than 8 characters,
     the function returns zero.
     """
-    try:
-        return int(os.environ['REFINERY_TERMSIZE'])
-    except (KeyError, ValueError):
-        pass
+    from refinery.lib.environment import environment
+    ev_terminal_size = environment.term_size.value
+    if ev_terminal_size > 0:
+        return ev_terminal_size
     width = default
     for stream in (sys.stderr, sys.stdout):
         if stream.isatty():
