@@ -4,7 +4,8 @@ import abc
 import re
 import io
 
-from typing import ByteString
+from functools import wraps
+from typing import ByteString, Callable
 from zlib import crc32
 
 from refinery.units import arg, Unit, RefineryPartialResult
@@ -83,3 +84,46 @@ class IterativeDeobfuscator(Deobfuscator, abstract=True):
         else:
             raise AutoDeobfuscationTimeout(data)
         return data
+
+
+class StringLiterals:
+
+    def __init__(self, pattern: str, data: str):
+        self.pattern = str(pattern)
+        self.update(data)
+
+    def update(self, data):
+        self.data = data
+        self.ranges = [
+            match.span() for match in re.finditer(self.pattern, data)
+        ]
+
+    def shift(self, by, start=0):
+        for k in range(start, len(self.ranges)):
+            a, b = self.ranges[k]
+            self.ranges[k] = a + by, b + by
+
+    def outside(self, function: Callable[[re.Match], str]) -> Callable[[re.Match], str]:
+        @wraps(function)
+        def wrapper(match: re.Match) -> str:
+            if match.string != self.data:
+                self.update(match.string)
+            a, b = match.span()
+            for x, y in self.ranges:
+                if x > b: break
+                if (a in range(x, y) or x in range(a, b)) and (x < a or y > b):
+                    return match[0]
+            result = function(match)
+            if result is not None:
+                return result
+            return match[0]
+        return wrapper
+
+    def __contains__(self, index):
+        return any(index in range(*L) for L in self.ranges)
+
+    def get_container(self, offset):
+        for k, L in enumerate(self.ranges):
+            if offset in range(*L):
+                return k
+        return None
